# General enumerations

These are the enumeration classes from DSS-Python-Backend, reexported as `dss.enums` in DSS-Python.

We recommend using them directly from DSS-Python (`from dss import SolveModes`, for example). Many functions allow using these for better code quality, and some are required to correctly use the extended API. Note that AltDSS-Python includes a lot more enumerations derived from the internal DSS schema.

For the extra enumerations available only in AltDSS-Python, see the [`altdss.enums` API reference](altdss.enums).

```{include} ../../dss-extensions/docs/python/enums.md
```
